<?php

declare(strict_types=1);

namespace Dedi\SyliusCmsPlugin\Utils\BlockList;

use MonsieurBiz\SyliusRichEditorPlugin\UiElement\Registry;
use MonsieurBiz\SyliusRichEditorPlugin\UiElement\UiElementInterface;

class BlockList implements BlockListInterface
{
    public const TAG = 'embeddable';

    private Registry $registry;

    public function __construct(Registry $registry)
    {
        $this->registry = $registry;
    }

    public function getList(): array
    {
        return array_reduce($this->registry->getUiElements(), function (array $list, UiElementInterface $element) {
            $data = $element->jsonSerialize();

            if (in_array(self::TAG, $data['tags']) && !$data['ignored']) {
                $list[] = [
                    'name' => $this->formatCode($element->getCode()),
                    'type' => $element->getFormClass(),
                    'label' => $element->getTitle(),
                    'shop_template' => $element->getFrontRenderTemplate(),
                    'admin_template' => $element->getAdminRenderTemplate(),
                ];
            }

            return $list;
        }, []);
    }

    public function getElementByName(string $name): ?array
    {
        foreach ($this->getList() as $item) {
            if ($item['name'] === $name) {
                return $item;
            }
        }

        return null;
    }

    private function formatCode(string $code): string
    {
        return str_replace('.', '_', $code);
    }
}
